@@ -10,6 +10,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "base/basic_types.h"
 #include <gsl/gsl>
 #include <gsl/gsl_byte>
+#include <vector>
+#include <array>
 
 namespace bytes {
 
