@@ -26,6 +26,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "chat_helpers/message_field.h"
 #include "history/history.h"
 #include "history/history_message.h"
+#include "history/view/history_view_schedule_box.h"
 #include "window/themes/window_theme.h"
 #include "window/window_session_controller.h"
 #include "boxes/peer_list_box.h"
@@ -195,7 +196,7 @@ void ShareBox::prepareCommentField() {
 	const auto field = _comment->entity();
 
 	connect(field, &Ui::InputField::submitted, [=] {
-		submit();
+		submit({});
 	});
 
 	field->setInstantReplaces(Ui::InstantReplaces::Default());
@@ -242,7 +243,7 @@ void ShareBox::prepare() {
 	_select->setSubmittedCallback([=](Qt::KeyboardModifiers modifiers) {
 		if (modifiers.testFlag(Qt::ControlModifier)
 			|| modifiers.testFlag(Qt::MetaModifier)) {
-			submit();
+			submit({});
 		} else {
 			_inner->selectActive();
 		}
@@ -408,16 +409,24 @@ void ShareBox::keyPressEvent(QKeyEvent *e) {
 	}
 }
 
+SendMenuType ShareBox::sendMenuType() const {
+	const auto selected = _inner->selected();
+	return (selected.size() == 1 && selected.front()->isSelf())
+		? SendMenuType::Reminder
+		: SendMenuType::Scheduled;
+}
+
 void ShareBox::createButtons() {
 	clearButtons();
 	if (_hasSelected) {
 		const auto send = addButton(tr::lng_share_confirm(), [=] {
-			submit();
+			submit({});
 		});
-		SetupSendWithoutSound(
+		SetupSendMenu(
 			send,
-			[=] { return true; },
-			[=] { submit(true); });
+			[=] { return sendMenuType(); },
+			[=] { submitSilent(); },
+			[=] { submitScheduled(); });
 	} else if (_copyCallback) {
 		addButton(tr::lng_share_copy_link(), [=] { copyLink(); });
 	}
@@ -451,15 +460,28 @@ void ShareBox::innerSelectedChanged(PeerData *peer, bool checked) {
 	update();
 }
 
-void ShareBox::submit(bool silent) {
+void ShareBox::submit(Api::SendOptions options) {
 	if (_submitCallback) {
 		_submitCallback(
 			_inner->selected(),
 			_comment->entity()->getTextWithAppliedMarkdown(),
-			silent);
+			options);
 	}
 }
 
+void ShareBox::submitSilent() {
+	auto options = Api::SendOptions();
+	options.silent = true;
+	submit(options);
+}
+
+void ShareBox::submitScheduled() {
+	const auto callback = [=](Api::SendOptions options) { submit(options); };
+	Ui::show(
+		HistoryView::PrepareScheduleBox(this, sendMenuType(), callback),
+		LayerOption::KeepOther);
+}
+
 void ShareBox::copyLink() {
 	if (_copyCallback) {
 		_copyCallback();
