@@ -10,8 +10,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "boxes/abstract_box.h"
 #include <vector>
 
-enum LangKey : int;
-
 namespace Ui {
 class Radiobutton;
 } // namespace Ui
@@ -20,7 +18,7 @@ class SingleChoiceBox : public BoxContent {
 public:
 	SingleChoiceBox(
 		QWidget*,
-		LangKey title,
+		rpl::producer<QString> title,
 		const std::vector<QString> &optionTexts,
 		int initialSelection,
 		Fn<void(int)> callback);
@@ -29,7 +27,7 @@ protected:
 	void prepare() override;
 
 private:
-	LangKey _title;
+	rpl::producer<QString> _title;
 	std::vector<QString> _optionTexts;
 	int _initialSelection = 0;
 	Fn<void(int)> _callback;
