@@ -21,6 +21,10 @@ class SinglePlayer;
 class FrameRenderer;
 } // namespace Lottie;
 
+namespace Main {
+class Session;
+} // namespace Main
+
 namespace internal {
 
 struct StickerSuggestion {
@@ -41,7 +45,7 @@ class FieldAutocomplete final : public Ui::RpWidget {
 	Q_OBJECT
 
 public:
-	FieldAutocomplete(QWidget *parent);
+	FieldAutocomplete(QWidget *parent, not_null<Main::Session*> session);
 	~FieldAutocomplete();
 
 	bool clearFilteredBotCommands();
@@ -104,6 +108,7 @@ private:
 	void recount(bool resetScroll = false);
 	internal::StickerRows getStickerSuggestions();
 
+	const not_null<Main::Session*> _session;
 	QPixmap _cache;
 	internal::MentionRows _mrows;
 	internal::HashtagRows _hrows;
@@ -193,6 +198,7 @@ private:
 	void showPreview();
 	void selectByMouse(QPoint global);
 
+	QSize stickerBoundingBox() const;
 	void setupLottie(StickerSuggestion &suggestion);
 	void repaintSticker(not_null<DocumentData*> document);
 	std::shared_ptr<Lottie::FrameRenderer> getLottieRenderer();
