@@ -12,6 +12,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "base/variant.h"
 #include "base/timer.h"
 
+class BoxContent;
+
 namespace Main {
 class Session;
 } // namespace Main
@@ -201,6 +203,7 @@ private:
 
 	void setSection(Section section);
 	void displaySet(uint64 setId);
+	void checkHideWithBox(QPointer<BoxContent> box);
 	void installSet(uint64 setId);
 	void removeMegagroupSet(bool locally);
 	void removeSet(uint64 setId);
@@ -310,7 +313,7 @@ private:
 
 	Section _section = Section::Stickers;
 
-	uint64 _displayingSetId = 0;
+	bool _displayingSet = false;
 	uint64 _removingSetId = 0;
 
 	Footer *_footer = nullptr;
