@@ -12,26 +12,26 @@ namespace Core {
 EventFilter::EventFilter(
 	not_null<QObject*> parent,
 	not_null<QObject*> object,
-	Fn<bool(not_null<QEvent*>)> filter)
+	Fn<EventFilter::Result(not_null<QEvent*>)> filter)
 : QObject(parent)
 , _filter(std::move(filter)) {
 	object->installEventFilter(this);
 }
 
 bool EventFilter::eventFilter(QObject *watched, QEvent *event) {
-	return _filter(event);
+	return (_filter(event) == Result::Cancel);
 }
 
 not_null<QObject*> InstallEventFilter(
 		not_null<QObject*> object,
-		Fn<bool(not_null<QEvent*>)> filter) {
+		Fn<EventFilter::Result(not_null<QEvent*>)> filter) {
 	return InstallEventFilter(object, object, std::move(filter));
 }
 
 not_null<QObject*> InstallEventFilter(
 		not_null<QObject*> context,
 		not_null<QObject*> object,
-		Fn<bool(not_null<QEvent*>)> filter) {
+		Fn<EventFilter::Result(not_null<QEvent*>)> filter) {
 	return new EventFilter(context, object, std::move(filter));
 }
 
