@@ -21,6 +21,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "window/window_session_controller.h"
 #include "settings/settings_intro.h"
 
+#include <QtCore/QJsonDocument>
+#include <QtCore/QJsonObject>
+
 extern "C" {
 #include <openssl/rsa.h>
 #include <openssl/pem.h>
@@ -496,21 +499,7 @@ bool ParseCommonMap(
 		return false;
 	}
 	const auto platforms = document.object();
-	const auto platform = [&] {
-		if (Platform::IsWindows()) {
-			return "win";
-		} else if (Platform::IsMacOldBuild()) {
-			return "mac32";
-		} else if (Platform::IsMac()) {
-			return "mac";
-		} else if (Platform::IsLinux32Bit()) {
-			return "linux32";
-		} else if (Platform::IsLinux64Bit()) {
-			return "linux";
-		} else {
-			Unexpected("Platform in ParseCommonMap.");
-		}
-	}();
+	const auto platform = Platform::AutoUpdateKey();
 	const auto it = platforms.constFind(platform);
 	if (it == platforms.constEnd()) {
 		LOG(("Update Error: MTP platform '%1' not found in response."
@@ -618,7 +607,11 @@ HttpChecker::HttpChecker(bool testing) : Checker(testing) {
 }
 
 void HttpChecker::start() {
-	auto url = QUrl(Local::readAutoupdatePrefix() + qstr("/current"));
+	const auto updaterVersion = Platform::AutoUpdateVersion();
+	const auto path = Local::readAutoupdatePrefix()
+		+ qstr("/current")
+		+ (updaterVersion > 1 ? QString::number(updaterVersion) : QString());
+	auto url = QUrl(path);
 	DEBUG_LOG(("Update Info: requesting update state"));
 	const auto request = QNetworkRequest(url);
 	_manager = std::make_unique<QNetworkAccessManager>();
@@ -893,8 +886,10 @@ void MtpChecker::start() {
 		crl::on_main(this, [=] { fail(); });
 		return;
 	}
-	constexpr auto kFeed = "tdhbcfeed";
-	MTP::ResolveChannel(&_mtp, kFeed, [=](const MTPInputChannel &channel) {
+	const auto updaterVersion = Platform::AutoUpdateVersion();
+	const auto feed = "tdhbcfeed"
+		+ (updaterVersion > 1 ? QString::number(updaterVersion) : QString());
+	MTP::ResolveChannel(&_mtp, feed, [=](const MTPInputChannel &channel) {
 		_mtp.send(
 			MTPmessages_GetHistory(
 				MTP_inputPeerChannel(
