@@ -38,11 +38,22 @@ struct FileReferenceAccumulator {
 			push(data.vdocument());
 		});
 	}
+	void push(const MTPTheme &data) {
+		data.match([&](const MTPDtheme &data) {
+			if (const auto document = data.vdocument()) {
+				push(*document);
+			}
+		}, [&](const MTPDthemeDocumentNotModified &data) {
+		});
+	}
 	void push(const MTPWebPage &data) {
 		data.match([&](const MTPDwebPage &data) {
 			if (const auto document = data.vdocument()) {
 				push(*document);
 			}
+			if (const auto documents = data.vdocuments()) {
+				push(*documents);
+			}
 			if (const auto photo = data.vphoto()) {
 				push(*photo);
 			}
@@ -165,4 +176,8 @@ UpdatedFileReferences GetFileReferences(const MTPWallPaper &data) {
 	return GetFileReferencesHelper(data);
 }
 
+UpdatedFileReferences GetFileReferences(const MTPTheme &data) {
+	return GetFileReferencesHelper(data);
+}
+
 } // namespace Data
