@@ -15,8 +15,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "lang/lang_keys.h"
 #include "storage/storage_facade.h"
 #include "core/application.h"
+#include "main/main_account.h"
 //#include "storage/storage_feed_messages.h" // #feed
-#include "auth_session.h"
+#include "main/main_session.h"
 #include "observer_peer.h"
 #include "apiwrap.h"
 #include "mainwidget.h"
@@ -28,11 +29,12 @@ namespace {
 constexpr auto kLoadedChatsMinCount = 20;
 constexpr auto kShowChatNamesCount = 8;
 
-rpl::producer<int> PinnedDialogsInFolderMaxValue() {
+rpl::producer<int> PinnedDialogsInFolderMaxValue(
+		not_null<Main::Session*> session) {
 	return rpl::single(
 		rpl::empty_value()
 	) | rpl::then(
-		Core::App().configUpdates()
+		session->account().configUpdates()
 	) | rpl::map([=] {
 		return Global::PinnedDialogsInFolderMax();
 	});
@@ -53,7 +55,7 @@ rpl::producer<int> PinnedDialogsInFolderMaxValue() {
 Folder::Folder(not_null<Data::Session*> owner, FolderId id)
 : Entry(owner, this)
 , _id(id)
-, _chatsList(PinnedDialogsInFolderMaxValue())
+, _chatsList(PinnedDialogsInFolderMaxValue(&owner->session()))
 , _name(tr::lng_archived_name(tr::now)) {
 	indexNameParts();
 
