@@ -12,7 +12,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_session.h"
 #include "data/data_folder.h"
 #include "mainwidget.h"
-#include "auth_session.h"
+#include "main/main_session.h"
 #include "history/history_item.h"
 #include "history/history.h"
 #include "styles/style_dialogs.h" // st::dialogsTextWidthMin
@@ -49,7 +49,7 @@ Data::Session &Entry::owner() const {
 	return *_owner;
 }
 
-AuthSession &Entry::session() const {
+Main::Session &Entry::session() const {
 	return _owner->session();
 }
 
