@@ -52,6 +52,8 @@ public:
 		Ui::ScrollArea *scroll,
 		not_null<History*> history);
 
+	Main::Session &session() const;
+
 	void messagesReceived(PeerData *peer, const QVector<MTPMessage> &messages);
 	void messagesReceivedDown(PeerData *peer, const QVector<MTPMessage> &messages);
 
@@ -77,6 +79,7 @@ public:
 		not_null<const Element*> view,
 		int from,
 		int till) const;
+	void elementStartStickerLoop(not_null<const Element*> view);
 
 	void updateBotInfo(bool recount = true);
 
@@ -328,6 +331,8 @@ private:
 	style::cursor _cursor = style::cur_default;
 	SelectedItems _selected;
 
+	base::flat_set<not_null<const HistoryItem*>> _animatedStickersPlayed;
+
 	MouseAction _mouseAction = MouseAction::None;
 	TextSelectType _mouseSelectType = TextSelectType::Letters;
 	QPoint _dragStartPosition;
