@@ -9,7 +9,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 #include "history/history.h"
 #include "history/history_service.h"
-#include "history/media/history_media.h"
+#include "history/view/media/history_view_media.h"
 #include "history/history_item_components.h"
 #include "history/view/history_view_cursor_state.h"
 #include "data/data_abstract_structure.h"
