@@ -38,6 +38,11 @@ public:
 		int count = 0;
 		int canDeleteCount = 0;
 		int canForwardCount = 0;
+		int canSendNowCount = 0;
+	};
+	enum class Section {
+		History,
+		Scheduled,
 	};
 
 	TopBarWidget(
@@ -55,11 +60,14 @@ public:
 	}
 	void setAnimatingMode(bool enabled);
 
-	void setActiveChat(Dialogs::Key chat);
+	void setActiveChat(Dialogs::Key chat, Section section);
 
 	rpl::producer<> forwardSelectionRequest() const {
 		return _forwardSelection.events();
 	}
+	rpl::producer<> sendNowSelectionRequest() const {
+		return _sendNowSelection.events();
+	}
 	rpl::producer<> deleteSelectionRequest() const {
 		return _deleteSelection.events();
 	}
@@ -78,6 +86,7 @@ protected:
 private:
 	void refreshInfoButton();
 	void refreshLang();
+	void updateSearchVisibility();
 	void updateControlsGeometry();
 	void selectedShowCallback();
 	void updateInfoToggleActive();
@@ -112,17 +121,19 @@ private:
 	void refreshUnreadBadge();
 	void updateUnreadBadge();
 
-	not_null<Window::SessionController*> _controller;
+	const not_null<Window::SessionController*> _controller;
 	Dialogs::Key _activeChat;
+	Section _section = Section::History;
 
 	int _selectedCount = 0;
 	bool _canDelete = false;
 	bool _canForward = false;
+	bool _canSendNow = false;
 
 	Ui::Animations::Simple _selectedShown;
 
 	object_ptr<Ui::RoundButton> _clear;
-	object_ptr<Ui::RoundButton> _forward, _delete;
+	object_ptr<Ui::RoundButton> _forward, _sendNow, _delete;
 
 	object_ptr<Ui::IconButton> _back;
 	object_ptr<Ui::UnreadBadge> _unreadBadge = { nullptr };
@@ -148,6 +159,7 @@ private:
 	base::Timer _onlineUpdater;
 
 	rpl::event_stream<> _forwardSelection;
+	rpl::event_stream<> _sendNowSelection;
 	rpl::event_stream<> _deleteSelection;
 	rpl::event_stream<> _clearSelection;
 
