@@ -21,7 +21,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_channel.h"
 #include "data/data_chat.h"
 #include "data/data_session.h"
-#include "auth_session.h"
+#include "main/main_session.h"
 
 namespace Info {
 
