@@ -45,8 +45,7 @@ Widget::Widget(
 , _inner(setInnerWidget(::Settings::CreateSection(
 		_type,
 		this,
-		controller->parentController(),
-		_self))) {
+		controller->parentController()))) {
 	_inner->sectionShowOther(
 	) | rpl::start_with_next([=](Type type) {
 		controller->showSettings(type);
