@@ -10,7 +10,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "core/application.h"
 #include "storage/serialize_common.h"
 #include "storage/localstorage.h"
-#include "platform/platform_specific.h"
+#include "platform/platform_info.h"
 #include "boxes/confirm_box.h"
 #include "lang/lang_file_parser.h"
 #include "base/qthelp_regex.h"
@@ -27,9 +27,9 @@ constexpr auto kLangValuesLimit = 20000;
 
 std::vector<QString> PrepareDefaultValues() {
 	auto result = std::vector<QString>();
-	result.reserve(kLangKeysCount);
-	for (auto i = 0; i != kLangKeysCount; ++i) {
-		result.emplace_back(GetOriginalValue(LangKey(i)));
+	result.reserve(kKeysCount);
+	for (auto i = 0; i != kKeysCount; ++i) {
+		result.emplace_back(GetOriginalValue(ushort(i)));
 	}
 	return result;
 }
@@ -38,7 +38,7 @@ class ValueParser {
 public:
 	ValueParser(
 		const QByteArray &key,
-		LangKey keyIndex,
+		ushort keyIndex,
 		const QByteArray &value);
 
 	QString takeResult() {
@@ -55,7 +55,7 @@ private:
 	bool readTag();
 
 	const QByteArray &_key;
-	LangKey _keyIndex = kLangKeysCount;
+	ushort _keyIndex = kKeysCount;
 
 	QLatin1String _currentTag;
 	ushort _currentTagIndex = 0;
@@ -72,7 +72,10 @@ private:
 
 };
 
-ValueParser::ValueParser(const QByteArray &key, LangKey keyIndex, const QByteArray &value)
+ValueParser::ValueParser(
+	const QByteArray &key,
+	ushort keyIndex,
+	const QByteArray &value)
 : _key(key)
 , _keyIndex(keyIndex)
 , _currentTag("")
@@ -196,7 +199,7 @@ void ParseKeyValue(
 		const QByteArray &value,
 		Save &&save) {
 	const auto index = GetKeyIndex(QLatin1String(key));
-	if (index != kLangKeysCount) {
+	if (index != kKeysCount) {
 		ValueParser parser(key, index, value);
 		if (parser.parse()) {
 			save(index, parser.takeResult());
@@ -240,12 +243,12 @@ struct Instance::PrivateTag {
 
 Instance::Instance()
 : _values(PrepareDefaultValues())
-, _nonDefaultSet(kLangKeysCount, 0) {
+, _nonDefaultSet(kKeysCount, 0) {
 }
 
 Instance::Instance(not_null<Instance*> derived, const PrivateTag &)
 : _derived(derived)
-, _nonDefaultSet(kLangKeysCount, 0) {
+, _nonDefaultSet(kKeysCount, 0) {
 }
 
 void Instance::switchToId(const Language &data) {
@@ -291,16 +294,17 @@ void Instance::reset(const Language &data) {
 	_name = data.name;
 	_nativeName = data.nativeName;
 
-	_legacyId = kLegacyLanguageNone;
 	_customFilePathAbsolute = QString();
 	_customFilePathRelative = QString();
 	_customFileContent = QByteArray();
 	_version = 0;
 	_nonDefaultValues.clear();
 	for (auto i = 0, count = int(_values.size()); i != count; ++i) {
-		_values[i] = GetOriginalValue(LangKey(i));
+		_values[i] = GetOriginalValue(ushort(i));
 	}
 	ranges::fill(_nonDefaultSet, 0);
+
+	_idChanges.fire_copy(_id);
 }
 
 QString Instance::systemLangCode() const {
@@ -329,17 +333,23 @@ QString Instance::id() const {
 	return id(Pack::Current);
 }
 
+rpl::producer<QString> Instance::idChanges() const {
+	return _idChanges.events();
+}
+
 QString Instance::baseId() const {
 	return id(Pack::Base);
 }
 
 QString Instance::name() const {
-	return _name.isEmpty() ? getValue(lng_language_name) : _name;
+	return _name.isEmpty()
+		? getValue(tr::lng_language_name.base)
+		: _name;
 }
 
 QString Instance::nativeName() const {
 	return _nativeName.isEmpty()
-		? getValue(lng_language_name)
+		? getValue(tr::lng_language_name.base)
 		: _nativeName;
 }
 
@@ -538,6 +548,8 @@ void Instance::fillFromSerialized(
 		applyValue(nonDefaultStrings[i], nonDefaultStrings[i + 1]);
 	}
 	updatePluralRules();
+
+	_idChanges.fire_copy(_id);
 }
 
 void Instance::loadFromContent(const QByteArray &content) {
@@ -560,6 +572,8 @@ void Instance::fillFromCustomContent(
 	_pluralId = PluralCodeForCustom(absolutePath, relativePath);
 	_name = _nativeName = QString();
 	loadFromCustomContent(absolutePath, relativePath, content);
+
+	_idChanges.fire_copy(_id);
 }
 
 void Instance::loadFromCustomContent(
@@ -588,44 +602,6 @@ bool Instance::loadFromCustomFile(const QString &filePath) {
 	return false;
 }
 
-void Instance::fillFromLegacy(int legacyId, const QString &legacyPath) {
-	if (legacyId == kLegacyDefaultLanguage) {
-		_legacyId = legacyId;
-
-		// We suppose that user didn't switch to the default language,
-		// so we will suggest him to switch to his language if we get it.
-		//
-		// The old available languages (de/it/nl/ko/es/pt_BR) won't be
-		// suggested anyway, because everyone saw the suggestion in intro.
-		_id = QString();// str_const_toString(kLegacyLanguages[legacyId]);
-	} else if (legacyId == kLegacyCustomLanguage) {
-		auto absolutePath = QFileInfo(legacyPath).absoluteFilePath();
-		auto relativePath = QDir().relativeFilePath(absolutePath);
-		auto content = Lang::FileParser::ReadFile(absolutePath, relativePath);
-		if (!content.isEmpty()) {
-			_legacyId = legacyId;
-			fillFromCustomContent(absolutePath, relativePath, content);
-		}
-	} else if (legacyId > kLegacyDefaultLanguage && legacyId < base::array_size(kLegacyLanguages)) {
-		auto languageId = str_const_toString(kLegacyLanguages[legacyId]);
-		auto resourcePath = qsl(":/langs/lang_") + languageId + qsl(".strings");
-		auto content = Lang::FileParser::ReadFile(resourcePath, resourcePath);
-		if (!content.isEmpty()) {
-			_legacyId = legacyId;
-			_id = languageId;
-			_version = 0;
-			loadFromContent(content);
-		}
-	}
-	_id = LanguageIdOrDefault(ConvertLegacyLanguageId(_id));
-	if (!isCustom()) {
-		_pluralId = _id;
-	}
-	_name = _nativeName = QString();
-	_base = nullptr;
-	updatePluralRules();
-}
-
 // SetCallback takes two QByteArrays: key, value.
 // It is called for all key-value pairs in string.
 // ResetCallback takes one QByteArray: key.
@@ -635,27 +611,17 @@ void HandleString(
 		SetCallback setCallback,
 		ResetCallback resetCallback) {
 	string.match([&](const MTPDlangPackString &data) {
-		setCallback(qba(data.vkey), qba(data.vvalue));
+		setCallback(qba(data.vkey()), qba(data.vvalue()));
 	}, [&](const MTPDlangPackStringPluralized &data) {
-		const auto key = qba(data.vkey);
-		setCallback(
-			key + "#zero",
-			data.has_zero_value() ? qba(data.vzero_value) : QByteArray());
-		setCallback(
-			key + "#one",
-			data.has_one_value() ? qba(data.vone_value) : QByteArray());
-		setCallback(
-			key + "#two",
-			data.has_two_value() ? qba(data.vtwo_value) : QByteArray());
-		setCallback(
-			key + "#few",
-			data.has_few_value() ? qba(data.vfew_value) : QByteArray());
-		setCallback(
-			key + "#many",
-			data.has_many_value() ? qba(data.vmany_value) : QByteArray());
-		setCallback(key + "#other", qba(data.vother_value));
+		const auto key = qba(data.vkey());
+		setCallback(key + "#zero", data.vzero_value().value_or_empty());
+		setCallback(key + "#one", data.vone_value().value_or_empty());
+		setCallback(key + "#two", data.vtwo_value().value_or_empty());
+		setCallback(key + "#few", data.vfew_value().value_or_empty());
+		setCallback(key + "#many", data.vmany_value().value_or_empty());
+		setCallback(key + "#other", qba(data.vother_value()));
 	}, [&](const MTPDlangPackStringDeleted &data) {
-		auto key = qba(data.vkey);
+		auto key = qba(data.vkey());
 		resetCallback(key);
 		const auto postfixes = {
 			"#zero",
@@ -689,11 +655,11 @@ void Instance::applyDifference(
 
 void Instance::applyDifferenceToMe(
 		const MTPDlangPackDifference &difference) {
-	Expects(LanguageIdOrDefault(_id) == qs(difference.vlang_code));
-	Expects(difference.vfrom_version.v <= _version);
+	Expects(LanguageIdOrDefault(_id) == qs(difference.vlang_code()));
+	Expects(difference.vfrom_version().v <= _version);
 
-	_version = difference.vversion.v;
-	for (const auto &string : difference.vstrings.v) {
+	_version = difference.vversion().v;
+	for (const auto &string : difference.vstrings().v) {
 		HandleString(string, [&](auto &&key, auto &&value) {
 			applyValue(key, value);
 		}, [&](auto &&key) {
@@ -707,17 +673,17 @@ void Instance::applyDifferenceToMe(
 	}
 }
 
-std::map<LangKey, QString> Instance::ParseStrings(
+std::map<ushort, QString> Instance::ParseStrings(
 		const MTPVector<MTPLangPackString> &strings) {
-	auto result = std::map<LangKey, QString>();
+	auto result = std::map<ushort, QString>();
 	for (const auto &string : strings.v) {
 		HandleString(string, [&](auto &&key, auto &&value) {
-			ParseKeyValue(key, value, [&](LangKey key, QString &&value) {
+			ParseKeyValue(key, value, [&](ushort key, QString &&value) {
 				result[key] = std::move(value);
 			});
 		}, [&](auto &&key) {
 			auto keyIndex = GetKeyIndex(QLatin1String(key));
-			if (keyIndex != kLangKeysCount) {
+			if (keyIndex != kKeysCount) {
 				result.erase(keyIndex);
 			}
 		});
@@ -736,7 +702,7 @@ QString Instance::getNonDefaultValue(const QByteArray &key) const {
 
 void Instance::applyValue(const QByteArray &key, const QByteArray &value) {
 	_nonDefaultValues[key] = value;
-	ParseKeyValue(key, value, [&](LangKey key, QString &&value) {
+	ParseKeyValue(key, value, [&](ushort key, QString &&value) {
 		_nonDefaultSet[key] = 1;
 		if (!_derived) {
 			_values[key] = std::move(value);
@@ -761,7 +727,7 @@ void Instance::resetValue(const QByteArray &key) {
 	_nonDefaultValues.erase(key);
 
 	const auto keyIndex = GetKeyIndex(QLatin1String(key));
-	if (keyIndex != kLangKeysCount) {
+	if (keyIndex != kKeysCount) {
 		_nonDefaultSet[keyIndex] = 0;
 		if (!_derived) {
 			const auto base = _base
@@ -780,14 +746,21 @@ Instance &Current() {
 	return Core::App().langpack();
 }
 
-rpl::producer<QString> Viewer(LangKey key) {
+namespace details {
+
+QString Current(ushort key) {
+	return Lang::Current().getValue(key);
+}
+
+rpl::producer<QString> Viewer(ushort key) {
 	return rpl::single(
-		Current().getValue(key)
+		Lang::Current().getValue(key)
 	) | then(base::ObservableViewer(
-		Current().updated()
+		Lang::Current().updated()
 	) | rpl::map([=] {
-		return Current().getValue(key);
+		return Lang::Current().getValue(key);
 	}));
 }
 
+} // namespace details
 } // namespace Lang
