@@ -137,7 +137,7 @@ void ConfigLoader::addSpecialEndpoint(
 		const std::string &ip,
 		int port,
 		bytes::const_span secret) {
-	auto endpoint = SpecialEndpoint {
+	const auto endpoint = SpecialEndpoint {
 		dcId,
 		ip,
 		port,
@@ -198,7 +198,7 @@ void ConfigLoader::sendSpecialRequest() {
 void ConfigLoader::specialConfigLoaded(const MTPConfig &result) {
 	Expects(result.type() == mtpc_config);
 
-	auto &data = result.c_config();
+	const auto &data = result.c_config();
 	if (data.vdc_options().v.empty()) {
 		LOG(("MTP Error: config with empty dc_options received!"));
 		return;
