@@ -31,7 +31,7 @@ struct EditContactScheme {
 
 	QString aboutExisting;
 	QString newHeader;
-	Fn<QString()> newPlaceholder;
+	rpl::producer<QString> newPlaceholder;
 	QString aboutNew;
 	Fn<bool(const QString &value)> validate;
 	Fn<QString(const QString &value)> format;
