@@ -18,6 +18,11 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "storage/localstorage.h"
 #include "core/crash_reports.h"
 
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDesktopWidget>
+#include <QtGui/QDesktopServices>
+#include <qpa/qplatformnativeinterface.h>
+
 #include <Shobjidl.h>
 #include <shellapi.h>
 
@@ -48,8 +53,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include <intsafe.h>
 #include <guiddef.h>
 
-#include <qpa/qplatformnativeinterface.h>
-
 #ifndef DCX_USESTYLE
 #define DCX_USESTYLE 0x00010000
 #endif
