@@ -16,25 +16,27 @@ namespace Settings {
 
 int ExceptionUsersCount(const std::vector<not_null<PeerData*>> &exceptions);
 
-bool CheckEditCloudPassword();
-object_ptr<BoxContent> EditCloudPasswordBox(not_null<AuthSession*> session);
-void RemoveCloudPassword();
+bool CheckEditCloudPassword(not_null<::Main::Session*> session);
+object_ptr<BoxContent> EditCloudPasswordBox(
+	not_null<::Main::Session*> session);
+void RemoveCloudPassword(not_null<::Main::Session*> session);
 object_ptr<BoxContent> CloudPasswordAppOutdatedBox();
 
 void AddPrivacyButton(
+	not_null<Window::SessionController*> controller,
 	not_null<Ui::VerticalLayout*> container,
 	rpl::producer<QString> label,
 	ApiWrap::Privacy::Key key,
-	Fn<std::unique_ptr<EditPrivacyController>()> controller);
+	Fn<std::unique_ptr<EditPrivacyController>()> controllerFactory);
 
 class PrivacySecurity : public Section {
 public:
-	PrivacySecurity(QWidget *parent, not_null<UserData*> self);
+	PrivacySecurity(
+		QWidget *parent,
+		not_null<Window::SessionController*> controller);
 
 private:
-	void setupContent();
-
-	not_null<UserData*> _self;
+	void setupContent(not_null<Window::SessionController*> controller);
 
 };
 
