@@ -23,6 +23,13 @@ inline int bytesSize(bytes::const_span bytes) {
 	return sizeof(quint32) + bytes.size();
 }
 
+inline int colorSize() {
+	return sizeof(quint32);
+}
+
+void writeColor(QDataStream &stream, const QColor &color);
+QColor readColor(QDataStream &stream);
+
 struct ReadBytesVectorWrap {
 	bytes::vector &bytes;
 };
