@@ -11,6 +11,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/effects/animations.h"
 #include "styles/style_widgets.h"
 
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QTextEdit>
+
 class UserData;
 
 namespace Ui {
