@@ -9,6 +9,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 #include "window/themes/window_theme_preview.h"
 #include "window/themes/window_themes_embedded.h"
+#include "window/themes/window_theme_editor.h"
 #include "mainwidget.h"
 #include "main/main_session.h"
 #include "apiwrap.h"
@@ -17,6 +18,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "storage/file_upload.h"
 #include "base/parse_helper.h"
 #include "base/zlib_help.h"
+#include "base/unixtime.h"
 #include "data/data_session.h"
 #include "main/main_account.h" // Account::sessionValue.
 #include "ui/image/image.h"
@@ -25,22 +27,20 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "styles/style_widgets.h"
 #include "styles/style_history.h"
 
+#include <QtCore/QBuffer>
+
 namespace Window {
 namespace Theme {
 namespace {
 
 constexpr auto kThemeFileSizeLimit = 5 * 1024 * 1024;
-constexpr auto kThemeBackgroundSizeLimit = 4 * 1024 * 1024;
 constexpr auto kBackgroundSizeLimit = 25 * 1024 * 1024;
 constexpr auto kNightThemeFile = str_const(":/gui/night.tdesktop-theme");
 constexpr auto kMinimumTiledSize = 512;
 
 struct Applying {
-	QString pathRelative;
-	QString pathAbsolute;
-	QByteArray content;
+	Saved data;
 	QByteArray paletteForRevert;
-	Cached cached;
 	Fn<void()> overrideKeep;
 };
 
@@ -49,7 +49,7 @@ Applying GlobalApplying;
 
 inline bool AreTestingTheme() {
 	return !GlobalApplying.paletteForRevert.isEmpty();
-};
+}
 
 bool CalculateIsMonoColorImage(const QImage &image) {
 	if (!image.isNull()) {
@@ -225,37 +225,6 @@ void applyBackground(QImage &&background, bool tiled, Instance *out) {
 	}
 }
 
-bool loadThemeFromCache(const QByteArray &content, const Cached &cache) {
-	if (cache.paletteChecksum != style::palette::Checksum()) {
-		return false;
-	}
-	if (cache.contentChecksum != hashCrc32(content.constData(), content.size())) {
-		return false;
-	}
-
-	QImage background;
-	if (!cache.background.isEmpty()) {
-		QDataStream stream(cache.background);
-		QImageReader reader(stream.device());
-#ifndef OS_MAC_OLD
-		reader.setAutoTransform(true);
-#endif // OS_MAC_OLD
-		if (!reader.read(&background) || background.isNull()) {
-			return false;
-		}
-	}
-
-	if (!style::main_palette::load(cache.colors)) {
-		return false;
-	}
-	Background()->saveAdjustableColors();
-	if (!background.isNull()) {
-		applyBackground(std::move(background), cache.tiled, nullptr);
-	}
-
-	return true;
-}
-
 enum class LoadResult {
 	Loaded,
 	Failed,
@@ -290,19 +259,33 @@ bool loadBackground(zlib::FileToRead &file, QByteArray *outBackground, bool *out
 	return true;
 }
 
-bool loadTheme(
+bool LoadTheme(
 		const QByteArray &content,
-		Cached &cache,
 		const Colorizer &colorizer,
+		const std::optional<QByteArray> &editedPalette,
+		Cached *cache = nullptr,
 		Instance *out = nullptr) {
-	cache = Cached();
+	if (content.size() < 4) {
+		LOG(("Theme Error: Bad theme content size: %1").arg(content.size()));
+		return false;
+	}
+
+	if (cache) {
+		*cache = Cached();
+	}
 	zlib::FileToRead file(content);
 
+	const auto emptyColorizer = Colorizer();
+	const auto &paletteColorizer = editedPalette ? emptyColorizer : colorizer;
+
 	unz_global_info globalInfo = { 0 };
 	file.getGlobalInfo(&globalInfo);
 	if (file.error() == UNZ_OK) {
-		auto schemeContent = file.readFileContent("colors.tdesktop-theme", zlib::kCaseInsensitive, kThemeSchemeSizeLimit);
-		if (file.error() == UNZ_END_OF_LIST_OF_FILE) {
+		auto schemeContent = editedPalette.value_or(QByteArray());
+		if (schemeContent.isEmpty()) {
+			schemeContent = file.readFileContent("colors.tdesktop-theme", zlib::kCaseInsensitive, kThemeSchemeSizeLimit);
+		}
+		if (schemeContent.isEmpty()) {
 			file.clearError();
 			schemeContent = file.readFileContent("colors.tdesktop-palette", zlib::kCaseInsensitive, kThemeSchemeSizeLimit);
 		}
@@ -310,10 +293,12 @@ bool loadTheme(
 			LOG(("Theme Error: could not read 'colors.tdesktop-theme' or 'colors.tdesktop-palette' in the theme file."));
 			return false;
 		}
-		if (!loadColorScheme(schemeContent, colorizer, out)) {
+		if (!loadColorScheme(schemeContent, paletteColorizer, out)) {
 			return false;
 		}
-		Background()->saveAdjustableColors();
+		if (!out) {
+			Background()->saveAdjustableColors();
+		}
 
 		auto backgroundTiled = false;
 		auto backgroundContent = QByteArray();
@@ -338,30 +323,103 @@ bool loadTheme(
 			if (colorizer) {
 				Colorize(background, colorizer);
 			}
-			auto buffer = QBuffer(&cache.background);
-			if (!background.save(&buffer, "BMP")) {
-				LOG(("Theme Error: could not write background image as a BMP to cache."));
-				return false;
+			if (cache) {
+				auto buffer = QBuffer(&cache->background);
+				if (!background.save(&buffer, "BMP")) {
+					LOG(("Theme Error: could not write background image as a BMP to cache."));
+					return false;
+				}
+				cache->tiled = backgroundTiled;
 			}
-			cache.tiled = backgroundTiled;
-
-			applyBackground(std::move(background), cache.tiled, out);
+			applyBackground(std::move(background), backgroundTiled, out);
 		}
 	} else {
 		// Looks like it is not a .zip theme.
-		if (!loadColorScheme(content, colorizer, out)) {
+		if (!loadColorScheme(editedPalette.value_or(content), paletteColorizer, out)) {
 			return false;
 		}
-		Background()->saveAdjustableColors();
+		if (!out) {
+			Background()->saveAdjustableColors();
+		}
 	}
 	if (out) {
-		cache.colors = out->palette.save();
-	} else {
-		cache.colors = style::main_palette::save();
+		out->palette.finalize();
 	}
-	cache.paletteChecksum = style::palette::Checksum();
-	cache.contentChecksum = hashCrc32(content.constData(), content.size());
+	if (cache) {
+		if (out) {
+			cache->colors = out->palette.save();
+		} else {
+			cache->colors = style::main_palette::save();
+		}
+		cache->paletteChecksum = style::palette::Checksum();
+		cache->contentChecksum = hashCrc32(content.constData(), content.size());
+	}
+	return true;
+}
 
+bool InitializeFromCache(
+		const QByteArray &content,
+		const Cached &cache) {
+	if (cache.paletteChecksum != style::palette::Checksum()) {
+		return false;
+	}
+	if (cache.contentChecksum != hashCrc32(content.constData(), content.size())) {
+		return false;
+	}
+
+	QImage background;
+	if (!cache.background.isEmpty()) {
+		QDataStream stream(cache.background);
+		QImageReader reader(stream.device());
+#ifndef OS_MAC_OLD
+		reader.setAutoTransform(true);
+#endif // OS_MAC_OLD
+		if (!reader.read(&background) || background.isNull()) {
+			return false;
+		}
+	}
+
+	if (!style::main_palette::load(cache.colors)) {
+		return false;
+	}
+	Background()->saveAdjustableColors();
+	if (!background.isNull()) {
+		applyBackground(std::move(background), cache.tiled, nullptr);
+	}
+
+	return true;
+}
+
+[[nodiscard]] std::optional<QByteArray> ReadEditingPalette() {
+	auto file = QFile(EditingPalettePath());
+	return file.open(QIODevice::ReadOnly)
+		? std::make_optional(file.readAll())
+		: std::nullopt;
+}
+
+bool InitializeFromSaved(Saved &&saved) {
+	if (saved.object.content.size() < 4) {
+		LOG(("Theme Error: Could not load theme from '%1' (%2)"
+			).arg(saved.object.pathRelative
+			).arg(saved.object.pathAbsolute));
+		return false;
+	}
+
+	const auto editing = ReadEditingPalette();
+	GlobalBackground.createIfNull();
+	if (!editing && InitializeFromCache(saved.object.content, saved.cache)) {
+		return true;
+	}
+
+	const auto colorizer = ColorizerForTheme(saved.object.pathAbsolute);
+	if (!LoadTheme(saved.object.content, colorizer, editing, &saved.cache)) {
+		return false;
+	}
+	if (editing) {
+		Background()->setEditingTheme(ReadCloudFromText(*editing));
+	} else {
+		Local::writeTheme(saved);
+	}
 	return true;
 }
 
@@ -374,19 +432,76 @@ QImage validateBackgroundImage(QImage image) {
 	return image;
 }
 
-void WriteAppliedTheme() {
-	auto saved = Saved();
-	saved.pathRelative = GlobalApplying.pathRelative;
-	saved.pathAbsolute = GlobalApplying.pathAbsolute;
-	saved.content = std::move(GlobalApplying.content);
-	saved.cache = std::move(GlobalApplying.cached);
-	Local::writeTheme(saved);
-}
-
 void ClearApplying() {
 	GlobalApplying = Applying();
 }
 
+SendMediaReady PrepareWallPaper(const QImage &image) {
+	PreparedPhotoThumbs thumbnails;
+	QVector<MTPPhotoSize> sizes;
+
+	QByteArray jpeg;
+	QBuffer jpegBuffer(&jpeg);
+	image.save(&jpegBuffer, "JPG", 87);
+
+	const auto scaled = [&](int size) {
+		return image.scaled(
+			size,
+			size,
+			Qt::KeepAspectRatio,
+			Qt::SmoothTransformation);
+	};
+	const auto push = [&](const char *type, QImage &&image) {
+		sizes.push_back(MTP_photoSize(
+			MTP_string(type),
+			MTP_fileLocationToBeDeprecated(MTP_long(0), MTP_int(0)),
+			MTP_int(image.width()),
+			MTP_int(image.height()), MTP_int(0)));
+		thumbnails.emplace(type[0], std::move(image));
+	};
+	push("s", scaled(320));
+
+	const auto filename = qsl("wallpaper.jpg");
+	auto attributes = QVector<MTPDocumentAttribute>(
+		1,
+		MTP_documentAttributeFilename(MTP_string(filename)));
+	attributes.push_back(MTP_documentAttributeImageSize(
+		MTP_int(image.width()),
+		MTP_int(image.height())));
+	const auto id = rand_value<DocumentId>();
+	const auto document = MTP_document(
+		MTP_flags(0),
+		MTP_long(id),
+		MTP_long(0),
+		MTP_bytes(),
+		MTP_int(base::unixtime::now()),
+		MTP_string("image/jpeg"),
+		MTP_int(jpeg.size()),
+		MTP_vector<MTPPhotoSize>(sizes),
+		MTP_int(MTP::maindc()),
+		MTP_vector<MTPDocumentAttribute>(attributes));
+
+	return SendMediaReady(
+		SendMediaType::ThemeFile,
+		QString(), // filepath
+		filename,
+		jpeg.size(),
+		jpeg,
+		id,
+		0,
+		QString(),
+		PeerId(),
+		MTP_photoEmpty(MTP_long(0)),
+		thumbnails,
+		document,
+		QByteArray(),
+		0);
+}
+
+void ClearEditingPalette() {
+	QFile(EditingPalettePath()).remove();
+}
+
 } // namespace
 
 ChatBackground::AdjustableColor::AdjustableColor(style::color data)
@@ -394,6 +509,7 @@ ChatBackground::AdjustableColor::AdjustableColor(style::color data)
 , original(data->c) {
 }
 
+// They're duplicated in window_theme_editor_box.cpp:ReplaceAdjustableColors.
 ChatBackground::ChatBackground() : _adjustableColors({
 		st::msgServiceBg,
 		st::msgServiceBgSelected,
@@ -441,7 +557,7 @@ void ChatBackground::checkUploadWallPaper() {
 	}
 	if (!Data::IsCustomWallPaper(_paper)
 		|| _original.isNull()
-		|| testingPalette()) {
+		|| _editingTheme.has_value()) {
 		return;
 	}
 
@@ -485,7 +601,7 @@ void ChatBackground::set(const Data::WallPaper &paper, QImage image) {
 	const auto needResetAdjustable = Data::IsDefaultWallPaper(paper)
 		&& !Data::IsDefaultWallPaper(_paper)
 		&& !nightMode()
-		&& _themeAbsolutePath.isEmpty();
+		&& _themeObject.pathAbsolute.isEmpty();
 	if (Data::IsThemeWallPaper(paper) && _themeImage.isNull()) {
 		setPaper(Data::DefaultWallPaper());
 	} else {
@@ -631,7 +747,7 @@ bool ChatBackground::adjustPaletteRequired() {
 			|| Data::details::IsTestingDefaultWallPaper(_paper);
 	};
 
-	if (testingPalette()) {
+	if (_editingTheme.has_value()) {
 		return false;
 	} else if (isNonDefaultThemeOrBackground() || nightMode()) {
 		return !usingThemeBackground();
@@ -639,11 +755,27 @@ bool ChatBackground::adjustPaletteRequired() {
 	return !usingDefaultBackground();
 }
 
-bool ChatBackground::testingPalette() const {
-	const auto path = AreTestingTheme()
-		? GlobalApplying.pathAbsolute
-		: _themeAbsolutePath;
-	return IsPaletteTestingPath(path);
+std::optional<Data::CloudTheme> ChatBackground::editingTheme() const {
+	return _editingTheme;
+}
+
+void ChatBackground::setEditingTheme(const Data::CloudTheme &editing) {
+	_editingTheme = editing;
+}
+
+void ChatBackground::clearEditingTheme(ClearEditing clear) {
+	if (!_editingTheme) {
+		return;
+	}
+	_editingTheme = std::nullopt;
+	if (clear == ClearEditing::Temporary) {
+		return;
+	}
+	ClearEditingPalette();
+	if (clear == ClearEditing::RevertChanges) {
+		reapplyWithNightMode(std::nullopt, _nightMode);
+		KeepApplied();
+	}
 }
 
 void ChatBackground::adjustPaletteUsingBackground(const QImage &image) {
@@ -741,12 +873,13 @@ void ChatBackground::setTileNightValue(bool tile) {
 	_tileNightValue = tile;
 }
 
-void ChatBackground::setThemeAbsolutePath(const QString &path) {
-	_themeAbsolutePath = path;
+void ChatBackground::setThemeObject(const Object &object) {
+	_themeObject = object;
+	_themeObject.content = QByteArray();
 }
 
-QString ChatBackground::themeAbsolutePath() const {
-	return _themeAbsolutePath;
+const Object &ChatBackground::themeObject() const {
+	return _themeObject;
 }
 
 void ChatBackground::reset() {
@@ -800,9 +933,8 @@ void ChatBackground::setTestingTheme(Instance &&theme) {
 		|| Data::IsThemeWallPaper(_paper)
 		|| (Data::IsDefaultWallPaper(_paper)
 			&& !nightMode()
-			&& _themeAbsolutePath.isEmpty());
-	if (AreTestingTheme()
-		&& IsPaletteTestingPath(GlobalApplying.pathAbsolute)) {
+			&& _themeObject.pathAbsolute.isEmpty());
+	if (AreTestingTheme() && _editingTheme.has_value()) {
 		// Grab current background image if it is not already custom
 		// Use prepared pixmap, not original image, because we're
 		// for sure switching to a non-pattern wall-paper (testing editor).
@@ -835,8 +967,8 @@ void ChatBackground::setTestingDefaultTheme() {
 	notify(BackgroundUpdate(BackgroundUpdate::Type::TestingTheme, tile()), true);
 }
 
-void ChatBackground::keepApplied(const QString &path, bool write) {
-	setThemeAbsolutePath(path);
+void ChatBackground::keepApplied(const Object &object, bool write) {
+	setThemeObject(object);
 	if (Data::details::IsTestingEditorWallPaper(_paper)) {
 		setPaper(Data::CustomWallPaper());
 		_themeImage = QImage();
@@ -865,15 +997,15 @@ void ChatBackground::keepApplied(const QString &path, bool write) {
 bool ChatBackground::isNonDefaultThemeOrBackground() {
 	start();
 	return nightMode()
-		? (_themeAbsolutePath != NightThemePath()
+		? (_themeObject.pathAbsolute != NightThemePath()
 			|| !Data::IsThemeWallPaper(_paper))
-		: (!_themeAbsolutePath.isEmpty()
+		: (!_themeObject.pathAbsolute.isEmpty()
 			|| !Data::IsDefaultWallPaper(_paper));
 }
 
 bool ChatBackground::isNonDefaultBackground() {
 	start();
-	return _themeAbsolutePath.isEmpty()
+	return _themeObject.pathAbsolute.isEmpty()
 		? !Data::IsDefaultWallPaper(_paper)
 		: !Data::IsThemeWallPaper(_paper);
 }
@@ -911,29 +1043,30 @@ bool ChatBackground::nightMode() const {
 	return _nightMode;
 }
 
-void ChatBackground::toggleNightMode(std::optional<QString> themePath) {
-	const auto settingDefault = themePath.has_value();
+void ChatBackground::reapplyWithNightMode(
+		std::optional<QString> themePath,
+		bool newNightMode) {
+	const auto settingExactTheme = themePath.has_value();
+	const auto nightModeChanged = (newNightMode != _nightMode);
 	const auto oldNightMode = _nightMode;
-	const auto newNightMode = !_nightMode;
 	_nightMode = newNightMode;
-	auto read = settingDefault ? Saved() : Local::readThemeAfterSwitch();
-	auto path = read.pathAbsolute;
+	auto read = settingExactTheme ? Saved() : Local::readThemeAfterSwitch();
+	auto path = read.object.pathAbsolute;
 
 	_nightMode = oldNightMode;
 	auto oldTileValue = (_nightMode ? _tileNightValue : _tileDayValue);
 	const auto alreadyOnDisk = [&] {
-		if (read.content.isEmpty()) {
+		if (read.object.content.isEmpty()) {
 			return false;
 		}
 		auto preview = std::make_unique<Preview>();
-		preview->pathAbsolute = std::move(read.pathAbsolute);
-		preview->pathRelative = std::move(read.pathRelative);
-		preview->content = std::move(read.content);
+		preview->object = std::move(read.object);
 		preview->instance.cached = std::move(read.cache);
-		const auto loaded = loadTheme(
-			preview->content,
-			preview->instance.cached,
+		const auto loaded = LoadTheme(
+			preview->object.content,
 			ColorizerForTheme(path),
+			std::nullopt,
+			&preview->instance.cached,
 			&preview->instance);
 		if (!loaded) {
 			return false;
@@ -951,73 +1084,71 @@ void ChatBackground::toggleNightMode(std::optional<QString> themePath) {
 	// Theme editor could have already reverted the testing of this toggle.
 	if (AreTestingTheme()) {
 		GlobalApplying.overrideKeep = [=] {
-			_nightMode = newNightMode;
+			if (nightModeChanged) {
+				_nightMode = newNightMode;
 
-			// Restore the value, it was set inside theme testing.
-			(oldNightMode ? _tileNightValue : _tileDayValue) = oldTileValue;
+				// Restore the value, it was set inside theme testing.
+				(oldNightMode ? _tileNightValue : _tileDayValue) = oldTileValue;
+			}
 
+			const auto saved = std::move(GlobalApplying.data);
 			if (!alreadyOnDisk) {
 				// First-time switch to default night mode should write it.
-				WriteAppliedTheme();
+				Local::writeTheme(saved);
 			}
 			ClearApplying();
-			keepApplied(path, settingDefault);
+			keepApplied(saved.object, settingExactTheme);
 			if (tile() != _tileForRevert) {
 				Local::writeUserSettings();
 			}
-			Local::writeSettings();
-			if (!settingDefault && !Local::readBackground()) {
+			if (nightModeChanged) {
+				Local::writeSettings();
+			}
+			if (!settingExactTheme && !Local::readBackground()) {
 				set(Data::ThemeWallPaper());
 			}
 		};
 	}
 }
 
+void ChatBackground::toggleNightMode(std::optional<QString> themePath) {
+	reapplyWithNightMode(themePath, !_nightMode);
+}
+
 ChatBackground *Background() {
 	GlobalBackground.createIfNull();
 	return GlobalBackground.data();
 }
 
-bool Load(Saved &&saved) {
-	if (saved.content.size() < 4) {
-		LOG(("Theme Error: Could not load theme from '%1' (%2)"
-			).arg(saved.pathRelative
-			).arg(saved.pathAbsolute));
-		return false;
-	}
-
-	GlobalBackground.createIfNull();
-	if (loadThemeFromCache(saved.content, saved.cache)) {
-		Background()->setThemeAbsolutePath(saved.pathAbsolute);
-		return true;
-	}
-
-	const auto colorizer = ColorizerForTheme(saved.pathAbsolute);
-	if (!loadTheme(saved.content, saved.cache, colorizer)) {
-		return false;
-	}
-	Local::writeTheme(saved);
-	Background()->setThemeAbsolutePath(saved.pathAbsolute);
-	return true;
+bool IsEmbeddedTheme(const QString &path) {
+	return path.isEmpty() || path.startsWith(qstr(":/gui/"));
 }
 
-void Unload() {
+bool Initialize(Saved &&saved) {
+	if (InitializeFromSaved(std::move(saved))) {
+		Background()->setThemeObject(saved.object);
+		return true;
+	}
+	return false;
+}
+
+void Uninitialize() {
 	GlobalBackground.clear();
 	GlobalApplying = Applying();
 }
 
-bool Apply(const QString &filepath) {
-	if (auto preview = PreviewFromFile(filepath)) {
+bool Apply(
+		const QString &filepath,
+		const Data::CloudTheme &cloud) {
+	if (auto preview = PreviewFromFile(QByteArray(), filepath, cloud)) {
 		return Apply(std::move(preview));
 	}
 	return false;
 }
 
 bool Apply(std::unique_ptr<Preview> preview) {
-	GlobalApplying.pathRelative = std::move(preview->pathRelative);
-	GlobalApplying.pathAbsolute = std::move(preview->pathAbsolute);
-	GlobalApplying.content = std::move(preview->content);
-	GlobalApplying.cached = std::move(preview->instance.cached);
+	GlobalApplying.data.object = std::move(preview->object);
+	GlobalApplying.data.cache = std::move(preview->instance.cached);
 	if (GlobalApplying.paletteForRevert.isEmpty()) {
 		GlobalApplying.paletteForRevert = style::main_palette::save();
 	}
@@ -1027,14 +1158,11 @@ bool Apply(std::unique_ptr<Preview> preview) {
 
 void ApplyDefaultWithPath(const QString &themePath) {
 	if (!themePath.isEmpty()) {
-		if (auto preview = PreviewFromFile(themePath)) {
+		if (auto preview = PreviewFromFile(QByteArray(), themePath, {})) {
 			Apply(std::move(preview));
 		}
 	} else {
-		GlobalApplying.pathRelative = QString();
-		GlobalApplying.pathAbsolute = QString();
-		GlobalApplying.content = QByteArray();
-		GlobalApplying.cached = Cached();
+		GlobalApplying.data = Saved();
 		if (GlobalApplying.paletteForRevert.isEmpty()) {
 			GlobalApplying.paletteForRevert = style::main_palette::save();
 		}
@@ -1042,30 +1170,13 @@ void ApplyDefaultWithPath(const QString &themePath) {
 	}
 }
 
-bool ApplyEditedPalette(const QString &path, const QByteArray &content) {
-	Instance out;
+bool ApplyEditedPalette(const QByteArray &content) {
+	auto out = Instance();
 	if (!loadColorScheme(content, Colorizer(), &out)) {
 		return false;
 	}
-	out.cached.colors = out.palette.save();
-	out.cached.paletteChecksum = style::palette::Checksum();
-	out.cached.contentChecksum = hashCrc32(
-		content.constData(),
-		content.size());
-
-	GlobalApplying.pathRelative = path.isEmpty()
-		? QString()
-		: QDir().relativeFilePath(path);
-	GlobalApplying.pathAbsolute = path.isEmpty()
-		? QString()
-		: QFileInfo(path).absoluteFilePath();
-	GlobalApplying.content = content;
-	GlobalApplying.cached = out.cached;
-	if (GlobalApplying.paletteForRevert.isEmpty()) {
-		GlobalApplying.paletteForRevert = style::main_palette::save();
-	}
-	Background()->setTestingTheme(std::move(out));
-	KeepApplied();
+	style::main_palette::apply(out.palette);
+	Background()->notify(BackgroundUpdate(BackgroundUpdate::Type::ApplyingEdit, Background()->tile()), true);
 	return true;
 }
 
@@ -1080,10 +1191,44 @@ void KeepApplied() {
 		onstack();
 		return;
 	}
-	const auto path = GlobalApplying.pathAbsolute;
-	WriteAppliedTheme();
+	const auto saved = std::move(GlobalApplying.data);
+	Local::writeTheme(saved);
 	ClearApplying();
-	Background()->keepApplied(path, true);
+	Background()->keepApplied(saved.object, true);
+}
+
+void KeepFromEditor(
+		const QByteArray &originalContent,
+		const ParsedTheme &originalParsed,
+		const Data::CloudTheme &cloud,
+		const QByteArray &themeContent,
+		const ParsedTheme &themeParsed,
+		const QImage &background) {
+	ClearApplying();
+	const auto content = themeContent.isEmpty()
+		? originalContent
+		: themeContent;
+	auto saved = Saved();
+	auto &cache = saved.cache;
+	auto &object = saved.object;
+	cache.colors = style::main_palette::save();
+	cache.paletteChecksum = style::palette::Checksum();
+	cache.contentChecksum = hashCrc32(content.constData(), content.size());
+	cache.background = themeParsed.background;
+	cache.tiled = themeParsed.tiled;
+	object.cloud = cloud;
+	object.content = themeContent.isEmpty()
+		? originalContent
+		: themeContent;
+	object.pathAbsolute = object.pathRelative = CachedThemePath(
+		cloud.documentId);
+	Local::writeTheme(saved);
+	Background()->keepApplied(saved.object, true);
+	Background()->setThemeData(
+		base::duplicate(background),
+		themeParsed.tiled);
+	Background()->set(Data::ThemeWallPaper());
+	Background()->writeNewBackgroundSettings();
 }
 
 void Revert() {
@@ -1123,25 +1268,31 @@ void ToggleNightMode(const QString &path) {
 	Background()->toggleNightMode(path);
 }
 
-bool LoadFromFile(
-		const QString &path,
-		Instance *out,
-		QByteArray *outContent) {
-	*outContent = readThemeContent(path);
-	if (outContent->size() < 4) {
-		LOG(("Theme Error: Could not load theme from %1").arg(path));
-		return false;
-	}
-
-	const auto colorizer = ColorizerForTheme(path);
-	return loadTheme(*outContent,  out->cached, colorizer, out);
+void ResetToSomeDefault() {
+	Background()->reapplyWithNightMode(
+		IsNightMode() ? NightThemePath() : QString(),
+		IsNightMode());
 }
 
-bool IsPaletteTestingPath(const QString &path) {
-	if (path.endsWith(qstr(".tdesktop-palette"), Qt::CaseInsensitive)) {
-		return QFileInfo(path).exists();
-	}
-	return false;
+bool LoadFromFile(
+		const QString &path,
+		not_null<Instance*> out,
+		Cached *outCache,
+		not_null<QByteArray*> outContent) {
+	*outContent = readThemeContent(path);
+	const auto colorizer = ColorizerForTheme(path);
+	return LoadTheme(*outContent, colorizer, std::nullopt, outCache, out);
+}
+
+bool LoadFromContent(
+		const QByteArray &content,
+		not_null<Instance*> out,
+		Cached *outCache) {
+	return LoadTheme(content, Colorizer(), std::nullopt, outCache, out);
+}
+
+QString EditingPalettePath() {
+	return cWorkingDir() + "tdata/editing-theme.tdesktop-palette";
 }
 
 QColor CountAverageColor(const QImage &image) {
